@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2008-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
  *
  * @category  Horde
- * @copyright 2008-2015 Horde LLC
+ * @copyright 2008-2016 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -18,7 +18,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2008-2015 Horde LLC
+ * @copyright 2008-2016 Horde LLC
  * @license   http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @package   Imap_Client
  */
@@ -299,7 +299,9 @@ class Horde_Imap_Client_Search_Query implements Serializable
                 }
                 $cmds->add(array(
                     $key,
-                    new Horde_Imap_Client_Data_Format_Number($val['size'])
+                    new Horde_Imap_Client_Data_Format_Number(
+                        empty($val['size']) ? 0 : $val['size']
+                    )
                 ));
             }
         }
